unit RtStr;

{ RTStrContainer                                                }
{ Copyright 1996 R&T Software, Tomasz Stanczak                  }
{ CIS 100735,3273                                               }
{ WWW http://ourworld.compuserve.com/homepages/tomasz           }
{                                                               }
{ TRTStrContainer is what is says, a container for strings, so  }
{ that they can be defined and saved as a resource within a     }
{ form definition. It has only three properties:                }
{                                                               }
{ Items                                                         }
{   published list of strings.                                  }
{                                                               }
{ Values                                                        }
{   same as above, but it can be used to differentiate texts    }
{   shown to the user, and texts used within the application.   }
{   The texts saved as Values are thought to be internal ones.  }
{   Even that one can argue, that the same can be achieved with }
{   numbers (I mean using numbers within application, and       }
{   showing string pointed to by those numbers to the user) I   }
{   think short string are much mire readable.                  }
{                                                               }
{ Value[Index: string]                                          }
{   allow to access Items through Values, i.e.:                 }
{                                                               }
{     Items = ('Check','Credit Card','Cash');                   }
{     Values = ('CHK','CCD','CSH');                             }
{                                                               }
{     Value['CHK'] = 'Check';                                   }
{                                                               }
{ This approach can be easily incorporated to any component     }
{ with Strings property, like TListBox, TComboBox, etc.         }
{                                                               }
{                                                               }
{ This component is a freeware, so you're granted an unlimited  }
{ license to use it for anything you want, except that you're   }
{ not allowed to distribute and/or market it as your own work,  }
{ alone or as a part of any component or component libraries in }
{ source code or compiled DCUs.                                 }
{                                                               }
{ All rights not explicitly granted here are reserved by the    }
{ author.                                                       }
{                                                               }
{ There are no warranties implied or explicite. You cannot make }
{ me responsible for anything you do with this component and I  }
{ won't promise to support it.                                  }

{------Fixed compiler switches----------------------------------------}
{$B-   Short-circuit boolean expressions }
{$G+   80286+ type instructions }
{$I+   I/O checking via exceptions }
{$V-   Disable var string checking }
{$W-   No Windows realmode stack frame }
{$X+   Enable extended syntax }
{---------------------------------------------------------------------}

interface

uses
   SysUtils, Classes;

type
   TRtStrContainer = class(TComponent)
   private
   	FItems: TStrings;
      FValues: TStrings;
      function GetValue(const Index: string): string;
      procedure SetValue(const Index: string; const Value: string);
      procedure SetItems(Value: TStrings);
      procedure SetValues(Value: TStrings);
   public
		constructor Create(AOwner: TComponent); override;
		destructor Destroy; override;
		property Value[const Index: string]: string read GetValue write SetValue;
   published
		property Items: TStrings read FItems write SetItems;
		property Values: TStrings read FValues write SetValues;
   end;

procedure Register;

implementation

procedure Register;
begin
	RegisterComponents('RiT',[TRTStrContainer]);
end;

{ TRtStrContainer }
constructor TRtStrContainer.Create(AOwner: TComponent);
begin
	inherited Create(AOwner);
	FItems := TStringList.Create;
	FValues := TStringList.Create;
end;

destructor TRtStrContainer.Destroy;
begin
	FItems.Free;
	FValues.Free;
	inherited Destroy;
end;

function TRtStrContainer.GetValue(const Index: string): string;
var
	i: integer;
begin
	Result := '';
	i := FValues.IndexOf(Index);
   if (i>=0) and (i<=FItems.Count-1) then
		Result := FItems[i];
end;

procedure TRtStrContainer.SetValue(const Index: string; const Value: string);
var
	i: integer;
begin
	i := FValues.IndexOf(Index);
   if i>=0 then
   begin
   	if i<=FItems.Count-1 then
			FItems[i] := Value
      else
      begin
      	repeat
      		FItems.Add('');
	      until i<=FItems.Count-1;
			FItems[i] := Value;
      end;
   end;
end;

procedure TRtStrContainer.SetItems(Value: TStrings);
begin
	FItems.Assign(Value);
end;

procedure TRtStrContainer.SetValues(Value: TStrings);
begin
	FValues.Assign(Value);
end;

end.

